@@ -1,32 +1,11 @@
-/****************************************************************************
-**
-** Copyright (C) 2017 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2017 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "qbsprojectimporter.h"
 
-#include "qbsbuildconfiguration.h"
 #include "qbspmlogging.h"
+#include "qbsprojectmanagerconstants.h"
+#include "qbssession.h"
 
 #include <coreplugin/documentmanager.h>
 #include <projectexplorer/buildconfiguration.h>
@@ -36,21 +15,20 @@
 #include <projectexplorer/project.h>
 #include <projectexplorer/projectexplorer.h>
 #include <projectexplorer/projectexplorerconstants.h>
-#include <projectexplorer/projectmacroexpander.h>
 #include <projectexplorer/toolchain.h>
 #include <qtsupport/qtkitinformation.h>
-#include <utils/fileutils.h>
+#include <utils/filepath.h>
 #include <utils/hostosinfo.h>
 
-#include <qbs.h>
-
 #include <QFileInfo>
 
 using namespace ProjectExplorer;
 using namespace Utils;
 
-namespace QbsProjectManager {
-namespace Internal {
+namespace PEConstants = ProjectExplorer::Constants;
+namespace QbsConstants = QbsProjectManager::Constants;
+
+namespace QbsProjectManager::Internal {
 
 struct BuildGraphData
 {
@@ -62,10 +40,10 @@ struct BuildGraphData
     FilePath sysroot;
     QString buildVariant;
 };
-static BuildGraphData extractBgData(const qbs::Project::BuildGraphInfo &bgInfo)
+static BuildGraphData extractBgData(const QbsSession::BuildGraphInfo &bgInfo)
 {
     BuildGraphData bgData;
-    bgData.bgFilePath = FilePath::fromString(bgInfo.bgFilePath);
+    bgData.bgFilePath = bgInfo.bgFilePath;
     bgData.overriddenProperties = bgInfo.overriddenProperties;
     const QVariantMap &moduleProps = bgInfo.requestedProperties;
     const QVariantMap prjCompilerPathByLanguage
@@ -87,46 +65,41 @@ QbsProjectImporter::QbsProjectImporter(const FilePath &path) : QtProjectImporter
 {
 }
 
-static QString buildDir(const QString &projectFilePath, const Kit *k)
+static FilePath buildDir(const FilePath &projectFilePath, const Kit *k)
 {
-    const QString projectName = QFileInfo(projectFilePath).completeBaseName();
-    ProjectMacroExpander expander(projectFilePath, projectName, k, QString(),
-                                  BuildConfiguration::Unknown);
-    const QString projectDir
-            = Project::projectDirectory(FilePath::fromString(projectFilePath)).toString();
-    const QString buildPath = expander.expand(ProjectExplorerPlugin::buildDirectoryTemplate());
-    return FileUtils::resolvePath(projectDir, buildPath);
+    const QString projectName = projectFilePath.completeBaseName();
+    return BuildConfiguration::buildDirectoryFromTemplate(
+                Project::projectDirectory(projectFilePath),
+                projectFilePath, projectName, k, QString(), BuildConfiguration::Unknown, "qbs");
 }
 
-static bool hasBuildGraph(const QString &dir)
+static bool hasBuildGraph(const FilePath &dir)
 {
-    const QString &dirName = QFileInfo(dir).fileName();
-    return QFileInfo::exists(dir + QLatin1Char('/') + dirName + QLatin1String(".bg"));
+    return dir.pathAppended(dir.fileName() + ".bg").exists();
 }
 
-static QStringList candidatesForDirectory(const QString &dir)
+static FilePaths candidatesForDirectory(const FilePath &dir)
 {
-    QStringList candidates;
-    const QStringList &subDirs = QDir(dir).entryList(QDir::Dirs | QDir::NoDotAndDotDot);
-    for (const QString &subDir : subDirs) {
-        const QString absSubDir = dir + QLatin1Char('/') + subDir;
-        if (hasBuildGraph(absSubDir))
-            candidates << absSubDir;
+    FilePaths candidates;
+    const FilePaths subDirs = dir.dirEntries(QDir::Dirs | QDir::NoDotAndDotDot);
+    for (const FilePath &subDir : subDirs) {
+        if (hasBuildGraph(subDir))
+            candidates << subDir;
     }
     return candidates;
 }
 
-QStringList QbsProjectImporter::importCandidates()
+FilePaths QbsProjectImporter::importCandidates()
 {
-    const QString projectDir = projectFilePath().toFileInfo().absolutePath();
-    QStringList candidates = candidatesForDirectory(projectDir);
+    const FilePath projectDir = projectFilePath().absolutePath();
+    FilePaths candidates = candidatesForDirectory(projectDir);
 
-    QSet<QString> seenCandidates;
+    QSet<FilePath> seenCandidates;
     seenCandidates.insert(projectDir);
     const auto &kits = KitManager::kits();
     for (Kit * const k : kits) {
-        QFileInfo fi(buildDir(projectFilePath().toString(), k));
-        const QString candidate = fi.absolutePath();
+        FilePath bdir = buildDir(projectFilePath(), k);
+        const FilePath candidate = bdir.absolutePath();
         if (!seenCandidates.contains(candidate)) {
             seenCandidates.insert(candidate);
             candidates << candidatesForDirectory(candidate);
@@ -136,19 +109,21 @@ QStringList QbsProjectImporter::importCandidates()
     return candidates;
 }
 
-QList<void *> QbsProjectImporter::examineDirectory(const FilePath &importPath) const
+QList<void *> QbsProjectImporter::examineDirectory(const FilePath &importPath,
+                                                   QString *warningMessage) const
 {
+    Q_UNUSED(warningMessage)
     qCDebug(qbsPmLog) << "examining build directory" << importPath.toUserOutput();
     QList<void *> data;
-    const QString bgFilePath = importPath.toString() + QLatin1Char('/') + importPath.fileName()
-            + QLatin1String(".bg");
+    const FilePath bgFilePath = importPath.pathAppended(importPath.fileName() + ".bg");
     const QStringList relevantProperties({
             "qbs.buildVariant", "qbs.sysroot", "qbs.toolchain",
             "cpp.compilerPath", "cpp.compilerPathByLanguage",
             "Qt.core.binPath"
     });
-    const qbs::Project::BuildGraphInfo bgInfo
-            = qbs::Project::getBuildGraphInfo(bgFilePath, relevantProperties);
+
+    const QbsSession::BuildGraphInfo bgInfo = QbsSession::getBuildGraphInfo(
+                bgFilePath, relevantProperties);
     if (bgInfo.error.hasError()) {
         qCDebug(qbsPmLog) << "error getting build graph info:" << bgInfo.error.toString();
         return data;
@@ -167,10 +142,8 @@ bool QbsProjectImporter::matchKit(void *directoryData, const Kit *k) const
             && bgData->cxxCompilerPath.isEmpty()) {
         return true;
     }
-    const ToolChain * const cToolchain
-            = ToolChainKitAspect::toolChain(k, Constants::C_LANGUAGE_ID);
-    const ToolChain * const cxxToolchain
-            = ToolChainKitAspect::toolChain(k, Constants::CXX_LANGUAGE_ID);
+    const ToolChain * const cToolchain = ToolChainKitAspect::cToolChain(k);
+    const ToolChain * const cxxToolchain = ToolChainKitAspect::cxxToolChain(k);
     if (!bgData->cCompilerPath.isEmpty()) {
         if (!cToolchain)
             return false;
@@ -183,11 +156,11 @@ bool QbsProjectImporter::matchKit(void *directoryData, const Kit *k) const
         if (bgData->cxxCompilerPath != cxxToolchain->compilerCommand())
             return false;
     }
-    const QtSupport::BaseQtVersion * const qtVersion = QtSupport::QtKitAspect::qtVersion(k);
+    const QtSupport::QtVersion * const qtVersion = QtSupport::QtKitAspect::qtVersion(k);
     if (!bgData->qtBinPath.isEmpty()) {
         if (!qtVersion)
             return false;
-        if (bgData->qtBinPath != qtVersion->binPath())
+        if (bgData->qtBinPath != qtVersion->hostBinPath())
             return false;
     }
     if (bgData->sysroot != SysRootKitAspect::sysRoot(k))
@@ -203,16 +176,16 @@ Kit *QbsProjectImporter::createKit(void *directoryData) const
     qCDebug(qbsPmLog) << "creating kit for imported build" << bgData->bgFilePath.toUserOutput();
     QtVersionData qtVersionData;
     if (!bgData->qtBinPath.isEmpty()) {
-        const FilePath qmakeFilePath = bgData->qtBinPath.pathAppended(HostOsInfo::withExecutableSuffix("qmake"));
+        const FilePath qmakeFilePath = bgData->qtBinPath.pathAppended("qmake").withExecutableSuffix();
         qtVersionData = findOrCreateQtVersion(qmakeFilePath);
     }
     return createTemporaryKit(qtVersionData,[this, bgData](Kit *k) -> void {
         QList<ToolChainData> tcData;
         if (!bgData->cxxCompilerPath.isEmpty())
-            tcData << findOrCreateToolChains(bgData->cxxCompilerPath, Constants::CXX_LANGUAGE_ID);
+            tcData << findOrCreateToolChains({bgData->cxxCompilerPath, PEConstants::CXX_LANGUAGE_ID});
         if (!bgData->cCompilerPath.isEmpty())
-            tcData << findOrCreateToolChains(bgData->cCompilerPath, Constants::C_LANGUAGE_ID);
-        foreach (const ToolChainData &tc, tcData) {
+            tcData << findOrCreateToolChains({bgData->cCompilerPath, PEConstants::C_LANGUAGE_ID});
+        for (const ToolChainData &tc : std::as_const(tcData)) {
             if (!tc.tcs.isEmpty())
                 ToolChainKitAspect::setToolChain(k, tc.tcs.first());
         }
@@ -220,25 +193,19 @@ Kit *QbsProjectImporter::createKit(void *directoryData) const
     });
 }
 
-const QList<BuildInfo> QbsProjectImporter::buildInfoListForKit(const Kit *k, void *directoryData) const
+const QList<BuildInfo> QbsProjectImporter::buildInfoList(void *directoryData) const
 {
-    qCDebug(qbsPmLog) << "creating build info for kit" << k->displayName();
-    const auto factory = qobject_cast<QbsBuildConfigurationFactory *>(
-                BuildConfigurationFactory::find(k, projectFilePath().toString()));
-    if (!factory) {
-        qCDebug(qbsPmLog) << "no build config factory found";
-        return {};
-    }
     const auto * const bgData = static_cast<BuildGraphData *>(directoryData);
-    BuildInfo info(factory);
-    info.displayName = bgData->bgFilePath.toFileInfo().completeBaseName();
-    info.buildType = bgData->buildVariant == "debug"
-            ? BuildConfiguration::Debug : BuildConfiguration::Release;
-    info.kitId = k->id();
+    BuildInfo info;
+    info.displayName = bgData->bgFilePath.completeBaseName();
+    info.buildType = bgData->buildVariant == QbsConstants::QBS_VARIANT_PROFILING
+            ? BuildConfiguration::Profile : bgData->buildVariant == QbsConstants::QBS_VARIANT_RELEASE
+            ? BuildConfiguration::Release : BuildConfiguration::Debug;
     info.buildDirectory = bgData->bgFilePath.parentDir().parentDir();
     QVariantMap config = bgData->overriddenProperties;
     config.insert("configName", info.displayName);
     info.extraInfo = config;
+    qCDebug(qbsPmLog) << "creating build info for " << info.displayName << ' ' << bgData->buildVariant;
     return {info};
 }
 
@@ -247,5 +214,4 @@ void QbsProjectImporter::deleteDirectoryData(void *directoryData) const
     delete static_cast<BuildGraphData *>(directoryData);
 }
 
-} // namespace Internal
-} // namespace QbsProjectManager
+} // QbsProjectManager::Internal
